@@ -1,4 +1,4 @@
-ncvreg <- function(X, y, family=c("gaussian","binomial"), penalty=c("MCP", "SCAD", "lasso"), gamma=switch(penalty, SCAD=3.7, 3), alpha=1, lambda.min=ifelse(n>p,.001,.05), nlambda=100, lambda, eps=.001, max.iter=1000, convex=TRUE, dfmax=p+1, penalty.factor=rep(1, ncol(X)), warn=TRUE, returnX=FALSE, ...)
+ncvreg <- function(X, y, family=c("gaussian","binomial","poisson"), penalty=c("MCP", "SCAD", "lasso"), gamma=switch(penalty, SCAD=3.7, 3), alpha=1, lambda.min=ifelse(n>p,.001,.05), nlambda=100, lambda, eps=.001, max.iter=1000, convex=TRUE, dfmax=p+1, penalty.factor=rep(1, ncol(X)), warn=TRUE, returnX=FALSE, ...)
 {
   ## Error checking
   family <- match.arg(family)
@@ -43,6 +43,11 @@ ncvreg <- function(X, y, family=c("gaussian","binomial"), penalty=c("MCP", "SCAD
     b <- rbind(res[[1]], matrix(res[[2]], p, nlambda))
     loss <- res[[3]]
     iter <- res[[4]]
+  } else if (family=="poisson") {
+    res <- .Call("cdfit_poisson", XX, as.numeric(yy), penalty, lambda, eps, as.integer(max.iter), as.double(gamma), penalty.factor, alpha, as.integer(dfmax), as.integer(user.lambda | any(penalty.factor==0)), as.integer(warn))
+    b <- rbind(res[[1]], matrix(res[[2]], p, nlambda))
+    loss <- res[[3]]
+    iter <- res[[4]]
   }
   
   ## Eliminate saturated lambda values, if any
@@ -51,7 +56,7 @@ ncvreg <- function(X, y, family=c("gaussian","binomial"), penalty=c("MCP", "SCAD
   iter <- iter[ind]
   lambda <- lambda[ind]
   loss <- loss[ind]
-  if (warn & any(iter==max.iter)) warning("Algorithm failed to converge for all values of lambda")
+  if (warn & any(iter==max.iter)) warning("Algorithm failed to converge for some values of lambda")
 
   ## Local convexity?
   convex.min <- if (convex) convexMin(b, XX, penalty, gamma, lambda*(1-alpha), family) else NULL
@@ -81,6 +86,7 @@ ncvreg <- function(X, y, family=c("gaussian","binomial"), penalty=c("MCP", "SCAD
                         penalty.factor = penalty.factor,
                         n = n),
                    class = "ncvreg")
+  if (family=="poisson") val$y <- y
   if (returnX) {
     val$X <- XX
     val$center <- center
