@@ -1,5 +1,4 @@
-setupLambda <- function(X, y, family, alpha, lambda.min, nlambda, penalty.factor)
-{
+setupLambda <- function(X, y, family, alpha, lambda.min, nlambda, penalty.factor) {
   n <- nrow(X)
   p <- ncol(X)
   
@@ -9,11 +8,11 @@ setupLambda <- function(X, y, family, alpha, lambda.min, nlambda, penalty.factor
     fit <- glm(y~X[, -ind], family=family)
   } else fit <- glm(y~1, family=family)
   if (family=="gaussian") {
-    z <- crossprod(X[,ind, drop=FALSE], fit$residuals) / n
+    zmax <- .Call("maxprod", X, fit$residuals, ind, penalty.factor) / n
   } else {
-    z <- crossprod(X[,ind, drop=FALSE], residuals(fit, "working") * fit$weights) / n
+    zmax <- .Call("maxprod", X, residuals(fit, "working") * fit$weights, ind, penalty.factor) / n
   }
-  lambda.max <- max(abs(z)/(alpha*penalty.factor[ind]))
+  lambda.max <- zmax/alpha
   
   if (lambda.min==0) lambda <- c(exp(seq(log(lambda.max),log(.001*lambda.max),len=nlambda-1)),0)
   else lambda <- exp(seq(log(lambda.max),log(lambda.min*lambda.max),len=nlambda))
