@@ -6,8 +6,6 @@
 #include <R_ext/Applic.h>
 double crossprod(double *X, double *y, int n, int j);
 double wcrossprod(double *X, double *y, double *w, int n, int j);
-double wsqsum(double *X, double *w, int n, int j);
-double sum(double *x, int n);
 int checkConvergence(double *beta, double *beta_old, double eps, int l, int J);
 double S(double z, double l);
 double MCP(double z, double l1, double l2, double gamma, double v);
@@ -120,7 +118,6 @@ SEXP cdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP lambda, SEXP eps_, SEX
 	INTEGER(iter)[l]++;
 	for (int j=0; j<p; j++) {
 	  if (e[j]) {
-	    // Rprintf("a: %f\n", a[j]);
 	    z[j] = crossprod(X, r, n, j)/n + a[j];
 
 	    // Update beta_j
@@ -129,7 +126,6 @@ SEXP cdfit_gaussian(SEXP X_, SEXP y_, SEXP penalty_, SEXP lambda, SEXP eps_, SEX
 	    if (strcmp(penalty,"MCP")==0) b[l*p+j] = MCP(z[j], l1, l2, gamma, 1);
 	    if (strcmp(penalty,"SCAD")==0) b[l*p+j] = SCAD(z[j], l1, l2, gamma, 1);
 	    if (strcmp(penalty,"lasso")==0) b[l*p+j] = lasso(z[j], l1, l2, 1);
-	    // if (j==0) Rprintf("b[0] = %f\n", b[l*p+j]);
 
 	    // Update r
 	    double shift = b[l*p+j] - a[j];
